from typing import Iterator, Tuple
from uuid import uuid4

import requests
from requests import Response


def _get(service: str, token: str, address: str = None) -> Response:
    if not address:
        cookie = f"PHPSESSID={token}"
    else:
        cookie = f"PHPSESSID={token}; MI={address}; wpcc=dismiss"

    headers = {
        "Accept": "application/json",
        "X-Requested-With": "XMLHttpRequest",
        "Connection": "close",
        "Cookie": cookie,
    }

    response = requests.get(
        url=f"https://www.minuteinbox.com/{service}",
        headers=headers,
        allow_redirects=True,
    )

    response.encoding = "utf-8-sig"
    return response


def inbox() -> Tuple[str, str]:
    token = str(uuid4()).replace("-", "")

    json = _get("index/index", token).json()
    return json["email"], token


def content(address: str, token: str, id: str) -> str:
    response = _get(f"email/id/{id}", token, address)

    return response.text


def refresh(address: str, token: str) -> Iterator[dict]:
    json = _get("index/refresh", token, address).json()

    for mail in json:
        sender_name, sender_address = mail["od"].split(" <")

        yield {
            "id": mail["id"],
            "sent_at": mail["kdy"],
            "is_new": mail["precteno"] == "new",
            "sender": {
                "name": sender_name,
                "address": sender_address[:-1],
            },
            "subject": mail["predmet"],
            "content": content(address, token, mail["id"]),
        }


def times(address: str, token: str) -> dict:
    json = _get("index/zivot", token, address).json()

    return {
        "created_at": json["ted"],
        "expires_at": json["konec"],
    }


def extend(address: str, token: str, seconds: int) -> dict:
    _get(f"expirace/{seconds}", token, address)



from datetime import datetime
from typing import Iterator

from minuteinbox import api


class Account:
    def __init__(self, **data):
        self.name: str = data["name"]
        self.address: str = data["address"]


class Mail:
    def __init__(self, **data):
        self.id: str = data["id"]
        self.sent_at: str = data["sent_at"]
        self.is_new: bool = data["is_new"]
        self.sender: Account = Account(**data["sender"])
        self.subject: str = data["subject"]
        self.content: str = data["content"]


class Inbox:
    def __init__(self, address: str = None, token: str = None):
        if not address and not token:
            address, token = api.inbox()

        self.address: str = address
        self.token: str = token

    @property
    def mails(self) -> Iterator[Mail]:
        for mail in api.refresh(self.address, self.token):
            yield Mail(**mail)

    def extend_10m(self):
        api.extend(self.address, self.token, seconds=4200)

    def extend_1h(self):
        api.extend(self.address, self.token, seconds=3600)

    def extend_1d(self):
        api.extend(self.address, self.token, seconds=86400)

    def extend_1w(self):
        api.extend(self.address, self.token, seconds=604800)

    @property
    def expires_in(self):
        times = api.times(self.address, self.token)

        if times["expires_at"] is None:
            raise ValueError(f"{self.address} has expired")

        created_at = datetime.strptime(times["created_at"], "%Y-%m-%d %H:%M:%S")
        expires_at = datetime.strptime(times["expires_at"], "%Y-%m-%d %H:%M:%S")

        return (expires_at - created_at).seconds



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['minuteinbox']

package_data = \
{'': ['*']}

install_requires = \
['requests>=2.28.1,<3.0.0']

setup_kwargs = {
    'name': 'minuteinbox',
    'version': '0.2.0',
    'description': 'Unofficial python wrapper for minuteinbox.com',
    'long_description': ' # minuteinbox\n\n[![Version](https://img.shields.io/pypi/v/minuteinbox?logo=pypi)](https://pypi.org/project/minuteinbox)\n[![Quality Gate Status](https://img.shields.io/sonar/alert_status/fedecalendino_minuteinbox?logo=sonarcloud&server=https://sonarcloud.io)](https://sonarcloud.io/dashboard?id=fedecalendino_minuteinbox)\n[![CodeCoverage](https://img.shields.io/sonar/coverage/fedecalendino_minuteinbox?logo=sonarcloud&server=https://sonarcloud.io)](https://sonarcloud.io/dashboard?id=fedecalendino_minuteinbox)\n\nUnofficial python wrapper for minuteinbox.com\n',
    'author': 'Fede Calendino',
    'author_email': 'fede@calendino.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/fedecalendino/minuteinbox',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<4.0',
}


setup(**setup_kwargs)
